@@ -2,6 +2,38 @@ COMMENT = '"""'
 
 
 def gcoms(s):
+    lines = s.splitlines()
+    coms = []
+    rem = []
+    in_cm = False
+    for l in lines:
+        i = l.find(COMMENT)
+        if i >= 0:
+            if not in_cm:
+                in_cm = True
+                coms.append( [l])
+                if l.find(COMMENT, i+len(COMMENT)) > 0:
+                    in_cm = False
+            else:
+                coms[-1].append(l)
+                in_cm = False
+        else:
+            if in_cm:
+                coms[-1].append(l)
+            else:
+                rem.append(l)
+    if sum( map(len, coms) ) + len(rem) != len(lines):
+        print("Very bad. Comment-lengths change. This function MUST preserve length")
+        import sys
+        sys.exit()
+
+    coms = ["\n".join(c) for c in coms]
+    rem = "\n".join(rem)
+    return coms, rem
+
+
+
+
     coms = []
     while True:
         i = s.find(COMMENT)
